@@ -1,3 +1,4 @@
+# frozen_string_literal: true
 module YARD
   module Handlers
     module Ruby
@@ -6,8 +7,9 @@ module YARD
         include Parser
 
         IGNORE_METHODS = Hash[*%w(alias alias_method autoload attr attr_accessor
-          attr_reader attr_writer extend include public private protected
-          private_constant).map {|n| [n, true] }.flatten]
+          attr_reader attr_writer extend include module_function public private
+          protected private_constant private_class_method public_class_method).
+          map {|n| [n, true] }.flatten]
 
         def handle_comments
           return if IGNORE_METHODS[caller_method]
@@ -22,13 +24,13 @@ module YARD
             attaching = true
           end
 
-          if macro = find_attached_macro
+          macro = find_attached_macro
+          if macro
             txt = macro.expand([caller_method, *call_params], statement.source)
             @docstring += "\n" + txt
 
-            if !attaching && txt.match(/^\s*@!/) # macro has a directive
-              return register_docstring(nil)
-            end
+            # macro may have a directive
+            return register_docstring(nil) if !attaching && txt.match(/^\s*@!/)
           elsif !statement.comments_hash_flag && !implicit_docstring?
             return register_docstring(nil)
           end
@@ -38,9 +40,9 @@ module YARD
             return register_docstring(nil)
           end
 
-          object = MethodObject.new(namespace, method_name, scope)
-          object.signature = method_signature
-          register(object)
+          register MethodObject.new(namespace, method_name, scope) do |o|
+            o.signature = method_signature
+          end
         end
 
         def register_docstring(object, docstring = @docstring, stmt = statement)
@@ -83,7 +85,7 @@ module YARD
         def macro_name_matches(macro)
           objs = [macro.method_object]
           if objs.first.type != :proxy && objs.first.respond_to?(:aliases)
-            objs.push(*objs.first.aliases)
+            objs.concat(objs.first.aliases)
           end
 
           objs.any? {|obj| obj.name.to_s == caller_method.to_s }
@@ -91,4 +93,4 @@ module YARD
       end
     end
   end
-end
\ No newline at end of file
+end
