@@ -1,3 +1,4 @@
+# frozen_string_literal: true
 require 'rubygems/specification'
 
 class Gem::Specification
@@ -12,14 +13,14 @@ class Gem::Specification
 
   undef has_rdoc?
   def has_rdoc?
-    @has_rdoc && @has_rdoc != 'yard'
+    (@has_rdoc ||= true) && @has_rdoc != 'yard'
   end
 
   alias has_yardoc? has_yardoc
 
   # has_rdoc should not be ignored!
   if respond_to?(:overwrite_accessor)
-    overwrite_accessor(:has_rdoc) { @has_rdoc }
+    overwrite_accessor(:has_rdoc) { @has_rdoc ||= true }
     overwrite_accessor(:has_rdoc=) {|v| @has_rdoc = v }
   else
     attr_accessor :has_rdoc
@@ -34,8 +35,16 @@ class Gem::Specification
     alias _dump_without_rdoc _dump
     alias _dump _dump_with_rdoc
 
-    @@default_value[:has_rdoc] = true if defined?(@@default_value)
-    @@attributes << 'has_rdoc' if defined?(@@attributes)
-    @@nil_attributes << 'has_rdoc' if defined?(@@nil_attributes)
+    if class_variable_defined?(:@@default_value)
+      if @@default_value.frozen?
+        t = @@default_value.dup
+        t[:has_rdoc] = true
+        @@default_value = t.freeze
+      else
+        @@default_value[:has_rdoc] = true
+      end
+    end
+    @@attributes << 'has_rdoc' if class_variable_defined?(:@@attributes)
+    @@nil_attributes << 'has_rdoc' if class_variable_defined?(:@@nil_attributes)
   end
 end
