@@ -1,7 +1,6 @@
-require File.dirname(__FILE__) + '/../spec_helper'
-require 'ostruct'
+# frozen_string_literal: true
 
-describe YARD::Server::Commands::LibraryCommand do
+RSpec.describe YARD::Server::Commands::LibraryCommand do
   before do
     allow(Templates::Engine).to receive(:render)
     allow(Templates::Engine).to receive(:generate)
