@@ -1,9 +1,10 @@
+# frozen_string_literal: true
 require File.dirname(__FILE__) + '/spec_helper'
 
-describe YARD::Templates::Engine.template(:default, :tags) do
+RSpec.describe YARD::Templates::Engine.template(:default, :tags) do
   before { Registry.clear }
-  
-  describe 'all known tags' do
+
+  describe "all known tags" do
     before do
       YARD.parse_string <<-'eof'
         # Comments
@@ -32,8 +33,32 @@ describe YARD::Templates::Engine.template(:default, :tags) do
       eof
     end
 
-    it "should render text format correctly" do
-      text_equals(Registry.at('#m').format, :tag001)
+    it "renders text format correctly" do
+      text_equals(Registry.at('#m').format(text_options), :tag001)
     end
   end
-end
\ No newline at end of file
+
+  describe "param tags on non-methods" do
+    it "does not display @param tags on non-method objects" do
+      YARD.parse_string <<-'eof'
+        # @param [#to_s] name the name
+        module Foo; end
+      eof
+
+      expect { Registry.at('Foo').format(html_options) }
+        .not_to raise_error
+    end
+  end
+
+  describe "option tags on non-methods" do
+    it "does not display @option tags on non-method objects" do
+      YARD.parse_string <<-'eof'
+        # @option opts name [#to_s] ('bar') the name
+        module Foo; end
+      eof
+
+      expect { Registry.at('Foo').format(html_options) }
+        .not_to raise_error
+    end
+  end
+end
