@@ -1,36 +1,43 @@
+# frozen_string_literal: true
 def init
   tags = Tags::Library.visible_tags - [:abstract, :deprecated, :note, :todo]
   create_tag_methods(tags - [:example, :option, :overload, :see])
-  sections :index, tags
+  sections :index, tags.map {|t| t.to_s.tr('.', '_').to_sym }
   sections.any(:overload).push(T('docstring'))
 end
 
 def return
   if object.type == :method
-    return if object.name == :initialize && object.scope == :instance
+    return if object.constructor?
     return if object.tags(:return).size == 1 && object.tag(:return).types == ['void']
   end
   tag(:return)
 end
 
+def param
+  tag(:param) if object.type == :method
+end
+
 private
 
 def tag(name, opts = nil)
   return unless object.has_tag?(name)
   opts ||= options_for_tag(name)
-  @no_names = true if opts[:no_names]
-  @no_types = true if opts[:no_types]
+  @no_names = opts[:no_names] ? true : false
+  @no_types = opts[:no_types] ? true : false
   @name = name
   out = erb('tag')
-  @no_names, @no_types = nil, nil
+  @no_names = nil
+  @no_types = nil
   out
 end
 
 def create_tag_methods(tags)
   tags.each do |tag|
-    next if respond_to?(tag)
+    tag_meth = tag.to_s.tr('.', '_')
+    next if respond_to?(tag_meth)
     instance_eval(<<-eof, __FILE__, __LINE__ + 1)
-      def #{tag}; tag(#{tag.inspect}) end
+      def #{tag_meth}; tag(#{tag.inspect}) end
     eof
   end
 end
